@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# TBlock - An anticapitalist ad-blocker that uses the hosts file
+# TBlock - An anti-capitalist ad-blocker that uses the hosts file
 # Copyright (C) 2021 Twann <twann@ctemplar.com>
 
 # This program is free software: you can redistribute it and/or modify
@@ -27,6 +27,7 @@ from colorama import Fore, Style
 from .tools import enable_protection, disable_protection, print_status, print_version_info, print_help
 from .config import check_dirs
 from .repo import sync_remote_repo
+from .hosts import generate_hosts
 from .rules import add_rules, list_rules, delete_rules
 from .converter import convert_filter, get_syntax
 from .utils import check_root, unlock_database
@@ -34,7 +35,7 @@ from .filters import subscribe_to_filters, show_filters, update_filters, update_
     list_filters, change_filters_permissions, change_filter_id, search_filters
 from .exceptions import FilterNotExists, MissingArgumentError, FilterSourceExistsError, NotSubscribingError, \
     RuleNotExistsError, InvalidBindAddress, SIGTERM, InvalidFilterSyntax, NetworkError, FilterNotCustomError, \
-    FilterExistsError
+    FilterExistsError, InvalidDomainError
 
 
 tblock_args = [
@@ -57,7 +58,8 @@ tblock_args = [
     '-L', '--list',
     '-Y', '--sync',
     '-H', '--update-hosts',
-    '-D', '--restore'
+    '-D', '--restore',
+    '-G', '--gen-hosts'
 ]
 
 tblock_opts = [
@@ -177,9 +179,9 @@ class TBlockcArguments:
             'force': [bool, False],
             'version': [bool, False],
             'comments': [bool, False],
-            'output': [str, None],
-            'syntax': [str, None],
-            'input-syntax': [str, None],
+            'output': [str, ''],
+            'syntax': [str, ''],
+            'input-syntax': [str, ''],
             'get-syntax': [bool, False],
             'zero': [bool, False]
         }
@@ -392,6 +394,9 @@ def parse_args_tblock() -> None:
     elif parser.action == 'restore':
         disable_protection(parser.options['force'])
 
+    elif parser.action == 'gen-hosts':
+        generate_hosts()
+
     else:
         pass    # This should never happen
 
@@ -431,10 +436,10 @@ def parse_args_tblockc() -> None:
 
                 convert_filter(
                     input_file=parser.filter_path,
-                    output_file=parser.options['output'][1],
-                    output_syntax=parser.options['syntax'][1],
+                    output_file=str(parser.options['output'][1]),
+                    output_syntax=str(parser.options['syntax'][1]),
                     hosts_default_ip=default_ip,
-                    input_syntax=parser.options['input-syntax'][1],
+                    input_syntax=str(parser.options['input-syntax'][1]),
                     comments=parser.options['comments'][1],
                     force=parser.options['force'][1]
                 )
@@ -446,7 +451,7 @@ def run() -> None:
         parse_args_tblock()
     except (PermissionError, FilterSourceExistsError, MissingArgumentError, FilterNotExists, NotSubscribingError,
             RuleNotExistsError, InvalidBindAddress, InvalidFilterSyntax, FileNotFoundError, NetworkError,
-            FilterExistsError, FilterNotCustomError, IsADirectoryError) as err:
+            FilterExistsError, FilterNotCustomError, IsADirectoryError, InvalidDomainError) as err:
         print(str(err).replace('[Errno 2] N', 'n').replace('[Errno 21] I', 'i'))
         unlock_database()
         sys.exit(1)
