@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# TBlock - An anticapitalist ad-blocker that uses the hosts file
+# TBlock - An anti-capitalist ad-blocker that uses the hosts file
 # Copyright (C) 2021 Twann <twann@ctemplar.com>
 
 # This program is free software: you can redistribute it and/or modify
@@ -99,3 +99,8 @@ class InvalidRulePolicy(TBlockError):
 class FilterReservedError(TBlockError):
     def __init__(self, *args):
         super(FilterReservedError, self).__init__(*args)
+
+
+class InvalidDomainError(TBlockError):
+    def __init__(self, *args):
+        super(InvalidDomainError, self).__init__(*args)
