@@ -19,12 +19,12 @@
 import json
 import os.path
 import sqlite3
-from xml.etree import ElementTree
 
 # External libraries
 import requests
 import urllib3
 from colorama import Fore, Style
+from defusedxml import ElementTree
 
 # Local libraries
 from .filters import Filter, get_all_from_rfr
