@@ -222,8 +222,7 @@ def delete_rules(rules: list, force: bool = False) -> None:
         raise PermissionError(f'{Fore.RED}ERROR: you need to run as root to perform this operation{Style.RESET_ALL}')
     elif not rules:
         raise MissingArgumentError(
-            f'{Fore.RED}ERROR: you need to specify at least one domain to delete from rules{Style.RESET_ALL}'
-        )
+            f'{Fore.RED}ERROR: you need to specify at least one domain to remove from the rules{Style.RESET_ALL}')
     elif not force and not prompt_user('You are about to delete rules for the following domains:', list_domains):
         raise SIGTERM()
     print(':: Deleting rules...')
