@@ -1,4 +1,4 @@
-# TBlock - An anticapitalist ad-blocker that uses the hosts file
+# TBlock - An anti-capitalist ad-blocker that uses the hosts file
 # Copyright (C) 2021 Twann <twann@ctemplar.com>
 
 # This program is free software: you can redistribute it and/or modify
@@ -164,7 +164,7 @@ def print_version_info(ad_blocker: bool) -> None:
 
     if ad_blocker:
         name = 'TBlock'
-        desc = 'An anticapitalist ad-blocker that uses the hosts file'
+        desc = 'An anti-capitalist ad-blocker that uses the hosts file'
     else:
         name = 'TBlockc'
         desc = 'TBlock\'s built-in filter converter'
