@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# TBlock - An anticapitalist ad-blocker that uses the hosts file
+# TBlock - An anti-capitalist ad-blocker that uses the hosts file
 # Copyright (C) 2021 Twann <twann@ctemplar.com>
 
 # This program is free software: you can redistribute it and/or modify
@@ -119,29 +119,19 @@ def prompt_user(message: str, list_of_elements: list = None) -> bool:
     if output_string:
         print(f'\n {output_string}\n')
     try:
-        answer = input(':: Are you sure to continue ? [y/n] ')
+        answer = _get_user_consent()
     except KeyboardInterrupt:
         return False
     else:
-        return answer.lower() == 'y'
+        return answer
 
 
-def is_valid_ip(ip: str) -> bool:
-    """Check whether an IP address is valid or not
-
-    Args:
-        ip (str): Tĥe IP address to check
-
-    Returns:
-        bool: True if IP address seems valid
-    """
-    if 7 <= len(ip) <= 15:
-        if len(re.findall(r"\.", ip)) == 3:
-            return True
-        else:
-            return False
+def _get_user_consent() -> bool:
+    answer = input(':: Are you sure to continue ? [y/n] ')
+    while 'n' != answer.lower() != 'y' and answer != '':
+        answer = input(':: Are you sure to continue ? [y/n] ')
     else:
-        return False
+        return answer.lower() == 'y' or answer == ''
 
 
 def download_file(url: str, output_path: str) -> None:
@@ -154,7 +144,7 @@ def download_file(url: str, output_path: str) -> None:
     online_file = requests.get(url, headers={'User-agent': 'Mozilla/5.0'})
     if online_file.status_code != 200:
         raise InvalidLinkError()
-    with open(os.path.relpath(output_path), 'wb') as f:
+    with open(os.path.realpath(output_path), 'wb') as f:
         f.write(online_file.content)
 
 
@@ -170,3 +160,18 @@ def extract_domain(url: str) -> str:
     if re.match(re.compile('.*://'), url):
         url = url.split('://')[1]
     return url.split('/')[0].split(':')[0].split('#')[0].split('?')[0]
+
+
+def is_valid_domain(domain: str) -> bool:
+    """Check if a domain seems valid
+
+    Args:
+        domain (str): The domain to check
+
+    Returns:
+        bool: True if domain is valid
+    """
+    if not re.match(re.compile(r'[$/&%^?:*()=,;#\"+\t_\\]'), domain):
+        return True
+    else:
+        return False
